@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # plugin script for News outputting news items from an rss feed
-# Copyright (C) 2011 David Glass <dsglass@gmail.com>
+# Copyright (C) 2012 David Glass <dsglass@gmail.com>
 # Copyright is GPLv3 or later, see /usr/share/common-licenses/GPL-3
 
 import feedparser
@@ -18,7 +18,7 @@ max_feeds = int(float(re.search("max_feeds\s*=\s*(.*)\s*", lines).group(1)))
 feed = feedparser.parse(rss_url)
 j = 1;
 for i in feed.entries:
-    print i.title + ".\n"
+    print i.title + ". ",
     if j >= max_feeds:
         break
     j = j + 1
